@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aws
 version: 0.13.0
-id: aws-0.13.0-cb423743fad8b7d9c51f923d4c84948f
-key: aws_8FAC0NmyEj63KMf0rXlBup
+id: aws-0.13.0-2177bee99f3a14e431954a5897c2edbc
+key: aws_C4L0dTO7BTx01szAFCX7P6
 license: BSD3
 copyright: See contributors list in README and LICENSE file
 maintainer: aristidb@gmail.com
@@ -55,27 +55,27 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aws-0.13.0
-hs-libraries: HSaws-0.13.0-8FAC0NmyEj63KMf0rXlBup
+hs-libraries: HSaws-0.13.0-C4L0dTO7BTx01szAFCX7P6
 depends:
-    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
-    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
+    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
+    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
+    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
+    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-conduit-2.1.8-288436503dec7c7ed70373ac0e4730a6
-    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
+    http-conduit-2.1.8-0cd87eafc953cbe4f675bdf50a2df8e2
+    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
     lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
@@ -83,15 +83,15 @@ depends:
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     safe-0.3.9-b613242f536083d5bb04920ede356aea
-    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
+    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    xml-conduit-1.3.4-e268a8d251308faa5ddb6ec5be7cd100
+    xml-conduit-1.3.4-afe40bd27d2aaa75347b019ed922ee43
 haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
 haddock-html: /usr/share/doc/haskell-aws/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
